ODTbrain documentation
======================

ODTbrain provides image reconstruction algorithms for Optical Diffraction Tomography with a Born and Rytov Approximation-based Inversion to compute the refractive index (n) in 2D and in 3D. This is the documentaion of ODTbrain version |release|.

.. toctree::
   :maxdepth: 4
   :caption: Contents:
   
   sec_introduction
   sec_code_reference
   sec_examples
   z_bib


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
